==> haskell-data-functor-logistic-0.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-5ILpMQaZ8VNHxVS4MrNloJ
key:                  data-functor-logistic-0.0-5ILpMQaZ8VNHxVS4MrNloJ
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  fe2f485eb5dc73a7c89907db8b2b781f
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-5ILpMQaZ8VNHxVS4MrNloJ
depends:
    base-4.17.2.1 distributive-0.6.2.1-KSaZMZhIRBz72Ncs7jcJ3k

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-functor-logistic-0.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-IgbKyvfjJas4yBsZRJwPNP
key:                  data-functor-logistic-0.0-IgbKyvfjJas4yBsZRJwPNP
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  a4f5b08fc47c498b3a389025046cc345
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-IgbKyvfjJas4yBsZRJwPNP
depends:
    base-4.17.2.1 distributive-0.6.2.1-7zQJwH2ROzh39CUoDKPpzV

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
